
import time

def add(*num):
    if type(num[0]) == int:
        a = 0
    else:
        a = ''
    for i in num:
        a += i
    return a


def strdel(a,b=[]):
    c = ''
    for i in range(len(a)):
        if not i in b:
            c += a[i]
    return c

def fib(nth=33):
    n1 = 0
    n2 = 1
    n3 = 0
    count = 2
    while count < nth:
        count += 1
        n3 = n1 + n2
        n1 = n2
        n2 = n3
    return n3

def exchange(a,b):
    c = a
    a = b
    b = c
    return [a,b]

def random():
    a = time.perf_counter()
    a *= 7874
    a %= 89792
    a *= 791725
    a %= 789677
    a *= 89473
    return a
#print(random())

def randint(a=0,b=89073298):
    ab = random()
    ab %= b+1-a
    ab += a
    return int(ab)

randseed = 0
init = False

def randLinear(a,b,sets=time.perf_counter()):
    global init,randseed
    if not init:
        randseed = sets
        init = True
    randseed *= 8972135
    randseed %= 7893278
    randseed *= 7965219
    randseed %= 1895823
    randseed *= 78912
    randseed %= b-a
    randseed += a
    return randseed

#for i in range(100):
#    print(randLinear(0,100),randseed)
        
    





    



from sys import getsizeof
from SomeToolspbc.math import strdel

BIT = 1
B = BIT * 8
KB = B * 1024
MB = KB * 1024
GB = KB * 1024
TB = GB * 1024

pyStrA = 50
pyInt1 = 28
pyInt0 = 24
pyNone = 16

data = None

class reglist:
    def init(self,name,size=1024*1024*3):
        global data
        self.list = []
        self.size = size
        self.name = name
        self.now = 0
        data.append(f"{self.name} is init")
        if getsizeof(self.list) > self.size:
            raise ValueError(f"the {self.size} is too small!\
the size must bigger than {getsizeof(self.list)}")
    def getHave(self):
        return self.size - getsizeof(self.list)
    def append(self,a):
        self.list.append(a)
        self.now += 1
    def display(self):
        for i in range(len(self.list)):
            print(f'line {i}:',self.list[i])
    def clearMost(self):
        if getsizeof(self.list) > self.size:
            data.append(f'ERROR in regs,used space bigger than {self.size} ,so start clear {self.name}')
            while getsizeof(self.list) > self.size:
                del self.list[0]
                self.now -= 1
                if self.now < 0:
                    print("ERROR:size too small")
                    sys.exit(1)
                
            data.append(f'end clear {self.name}')
    def ch(self,a,thing):
        if a >= self.now:
            data.append(f'ERROR:no {a}')
class regdict:
    def init(self,name,size=1024*1024*3):
        global data
        self.list = {}
        self.size = size
        self.name = name
        data.append(f"{self.name} is init")
    def getHave(self):
        return self.size - getsizeof(self.list)
    def append(self,a,name):
        self.list[name]=a
    def display(self):
        for i in self.list:
            print(f'line {i}:',self.list[i])
    def clearMost(self):
        if getsizeof(self.list) > self.size:
            data.append(f'ERROR in regs,used space bigger than {self.size} ,so start clear {self.name}')
            while getsizeof(self.list) > self.size:
                for i in self.list:
                    del self.list[i]
                    if getsizeof(self.list) <= self.size:break
                #    print("ERROR:size too small")
                #    sys.exit(1)
            data.append(f'end clear {self.name}')
    def ch(self,a,thing):
        self.list[a]=thing
        
class regthing:
    def init(self,name,size=1024*1024*3):
        global data
        self.list = None
        self.size = size
        self.name = name
        self.now = 0
        data.append(f"{self.name} is init")
    def getHave(self):
        return self.size - getsizeof(self.list)
    def display(self):
        print(self.list)
    def clearMost(self):
        if getsizeof(self.list) > self.size:
            data.append(f'ERROR in regs,used space bigger than {self.size} ,so start clear {self.name}')
            if type(self.list) == int:
                self.list = -1
            elif type(self.list) == str:
                while getsizeof(self.list) > self.size:
                    self.list = strdel(self.list,[0])
            else:
                self.list = None
            data.append(f'end clear {self.name}')
    def ch(self,thing):
        self.list = thing
data=reglist()
data.init('data')



import tkinter,SomeToolspbc.math,copy


class windows:
    def __init__(self,w,h,x=0,y=0):
        self.win = tkinter.Tk()
        self.win.geometry(pytools.math.add(str(w),'x',str(h),'+',str(x),'+',str(y)))
        self.have = {}
    def add(self,obj,name=None):
        if name == None:
            self.have[len(self.bt)] = copy.copy(obj)
        else:
            self.have[name] = copy.copy(obj)
    def loop(self):
        self.win.mainloop()

class text:
    def __init__(self,txt,target):
        self.mine = tkinter.Label(target,text=txt)
    def ret(self):
        return self.mine

class button:
    def __init__(self,txt,target,command=None):
        self.mine = tkinter.Button(target,text=txt,command=command)
    def ret(self):
        return self.mine



from distutils.core import setup
 
setup(
    name='SomeToolspbc',  # 对外模块的名字
    version='2.0.1',  # 版本号
    description='some tools',  # 描述
    author='pbcat2022',  # 作者
    author_email='yuyao_100804@outlook.com',
    packages=['SomeToolspbc']
)


import os
class OpenFile:
    def __init__(self,name):
        self.file = name
    @property
    def readlines(self,mode='r'):
        with open(self.file,mode) as file:
            return file.readlines()
    @property
    def readline(self,mode='r'):
        with open(self.file,mode) as file:
            return file.readline()
    @property
    def read(self,mode='r'):
        with open(self.file,mode) as file:
            return file.read()
    def write(self,writes,mode='w'):
        with open(self.file,mode) as file:
            file.write(writes)
    def append(self,writes,mode='a'):
        with open(self.file,mode) as file:
            file.write(writes)
    def delFile(self):
        os.remove(self.file)

import zipfile
def zipFile(path,name):
    with zipfile.ZipFile(name,'w') as target:
        for i in os.walk(path):
            for n in i[2]:
                target.write(''.join((i[0],'/',n))) 
